# dotfiles

This is just a bunch of dotfiles.


## ArchLinux packages

Installing packages:

``` sh
# Base utils
pacman -S bat duf eza fish fisher htop inetutils jq kitty-terminfo neovim openssh tmux transmission-cli tree wget whois zellij
pacman -S shared-mime-info xdg-user-dirs
pacman -S reflector
pacman -S skim
pacman -S yazi unarchiver ffmpegthumbnailer fd ripgrep-all poppler zoxide
# Fonts
pacman -S nerd-fonts noto-fonts noto-fonts-emoji ttf-dejavu ttf-inconsolata ttf-liberation ttf-roboto
# Rust
pacman -S cargo-audit cargo-outdated cargo-release rustup
# Python
pacman -S python ruff uv
# Java
pacman -S java-runtime-common
# CLI software
pacman -S dog exiv2 gnupg imagemagick mkcert ncdu nmap pass playerctl python-shodan python-weasyprint qrencode rsync shellcheck sqlmap ssh-audit xsv yt-dlp
# Hyprland
pacman -S hyprland xdg-desktop-portal-hyprland qt5-wayland qt6-wayland
pacman -S pipewire wireplumber pipewire-audio pipewire-alsa pipewire-pulse pipewire-jack pipewire-x11-bell
pacman -S brightnessctl dunst fuzzel hyprpaper otf-font-awesome udiskie waybar wl-clipboard
pacman -S grim slurp
pacman -S swaylock
# Graphical software
pacman -S atril firefox gedit gimp handbrake kitty mpv openshot pcmanfm-gtk3 rhythmbox ristretto sweethome3d tumbler thunderbird vlc
pacman -S gvfs xarchiver
# Archives
pacman -S unrar p7zip zip unzip minizip
# Command-line copy/paste utilities
pacman -S wl-clipboard xclip
# MS-DOS
pacman -S dosfstools mtools
# AUR
pacman -S pacman-contrib namcap
# Smartcards
pacman -S ccid libnfc mfoc opensc pcsc-tools pcsclite
```

### Arch User Repository

Installing yay:

``` sh
mkdir -p "$HOME/projects/builds"
git clone "https://aur.archlinux.org/yay.git" "$HOME/projects/builds/yay"
cd "$HOME/projects/builds/yay"
makepkg
pacman -U "yay-<version>-x86_64.pkg.tar.zst"
```

Installing packages:

``` sh
# Vim plugin manager
yay -S vim-plug
# Printer
yay -S brother-dcp1610w brscan-skey brscan4
# Graphical software
yay -S cardpeek
```


## Fish

Install the Tide prompt:

```
fisher install IlanCosman/tide@v6
```

Configure the prompt:

```
tide configure
```


## Vim / Neovim

Compatibility workaround for Neovim:

```
ln -s .config/vim .vim
ln -s .config/vim/vimrc .vimrc
```

Plugins are managed by `vim-plug`, which is installed from the AUR.

``` sh
vim +PlugInstall # install all plugins
vim +PlugUpdate  # install or update all plugins
vim +PlugClean   # remove plugins no longer in the list
```


## Wallpaper

The wallpaper is randomly selected from images (png, jpg and jpeg) located in
the `$HOME/pictures/wallpapers/` directory.

Specific wallpapers for winter can be set in the `winter` sub-directory.


## /etc/locale.conf

```
cat >/etc/locale.conf << EOF
LANG=en_US.UTF-8
LC_ADDRESS=fr_FR.UTF-8
LC_MEASUREMENT=fr_FR.UTF-8
LC_PAPER=fr_FR.UTF-8
LC_TIME=fr_FR.UTF-8
EOF
```


## rtkit-daemon

By default, [rtkit-daemon][rtkit] tends to flood the system logs with not very
useful notifications:

```
déc. 31 14:16:56 lpt-01 rtkit-daemon[1347]: Supervising 12 threads of 9 processes of 1 users.
déc. 31 14:16:56 lpt-01 rtkit-daemon[1347]: Supervising 12 threads of 9 processes of 1 users.
déc. 31 14:17:00 lpt-01 rtkit-daemon[1347]: Supervising 12 threads of 9 processes of 1 users.
déc. 31 14:17:00 lpt-01 rtkit-daemon[1347]: Supervising 12 threads of 9 processes of 1 users.
```

This can be fixed by setting a higher log level:

```
sudo mkdir "/etc/systemd/system/rtkit-daemon.service.d"
echo "[Service]\nLogLevelMax=4" | sudo tee /etc/systemd/system/rtkit-daemon.service.d/log.conf >/dev/null
sudo systemctl daemon-reload
sudo systemctl restart rtkit-daemon.service
```

[rtkit]: https://archlinux.org/packages/extra/x86_64/rtkit/


## NetworkManager

To deactivate WiFi when a wired connection is up, have a look at example 15
from `man 7 nmcli-examples`.

TL; DR: copy and paste a script in
`/etc/NetworkManager/dispatcher.d/70-wifi-wired-exclusive.sh` and set it
executable.
